#' @name regressoR
#' @aliases regressoR
#' @docType package
#' @title Regression Data Analysis System
#' @author Oldemar Rodriguez Rojas \cr
#' Maintainer: Oldemar Rodriguez Rojas <oldemar.rodriguez@ucr.ac.cr>
#' @description
#' Perform a supervised data analysis on a database through a 'shiny' graphical interface. 
#' It includes methods such as linear regression, penalized regression, k-nearest neighbors, decision trees, ada boosting, 
#' extreme gradient boosting, random forest, neural networks, deep learning and support vector machines.
#' @details
#' \tabular{ll}{
#' Package: \tab regressoR\cr
#' Type: \tab Package\cr
#' Version: \tab 3.0.0\cr
#' Date: \tab 2023-02-15\cr
#' License: \tab GPL (>=2)\cr
#' }
#' @keywords package
#' @docType package

NULL
utils::globalVariables(c( "name", "value", "color"))